{% extends 'viewsets/edit.html' %}

{% block title_buttons %}
  {% if object.get_absolute_url %}
    <a class="btn btn-info float-right ml-1"
       href="{{ object.get_absolute_url() }}"
       target="_blank"><i class="far fa-eye"></i> {{ _('Show on site') }}</a>
  {% endif %}
{% endblock %}
