{% if widget.is_hidden %}
  {% include 'viewsets/widgets/wrapper.html' %}
{% else %}
  <div class="related-widget-wrapper align-items-center form-row">
    <div class="col mw-100">{% include 'viewsets/widgets/wrapper.html' %}</div>
    {% block links %}
      {% if can_add_related %}
        <div class="col-auto mr-2 ml-2" style="min-width: 1.5rem">
          <a class="related-widget-wrapper-link js-related-lookup"
             href="{{ add_related_url }}" data-related-for="{{ widget.attrs.id }}">
            <i class="fa fa-plus"> </i>
          </a>
        </div>
      {% endif %}
    {% endblock %}
  </div>
{% endif %}