<!doctype html>
<html class="no-js" lang="">
<head>
  <meta charset="utf-8">
  <meta http-equiv="x-ua-compatible" content="ie=edge">
  <title>{% block title %}{% endblock %}</title>
  <meta name="viewport" content="width=device-width, initial-scale=1, shrink-to-fit=no">

  {% block css %}
    <link rel="stylesheet" href="{{ static('viewsets/css/vendor/bootstrap.min.css') }}">
    <link rel="stylesheet" href="{{ static('viewsets/css/vendor/fontawesome.all.min.css') }}">
    <link rel="stylesheet" href="{{ static('viewsets/css/viewsets.css') }}">
  {% endblock %}

  {% block head_js %}
    <script src="{{ static('viewsets/js/vendor/jquery-3.4.1.min.js') }}"></script>
    <script src="{{ static('viewsets/js/vendor/bootstrap.min.js') }}"></script>
    <script src="{{ static('viewsets/js/related.js') }}"></script>
  {% endblock %}

  {% block extrahead %}{% endblock %}
</head>
<body>

{% block body %}
  <main role="main" class="container my-3">
    {% block breadcrumbs %}
      {% if not is_popup %}
        <nav aria-label="breadcrumb">
          <ul class="breadcrumb">
            {% block breadcrumbs_items %}{% endblock %}
          </ul>
        </nav>
      {% endif %}
    {% endblock %}

    {% block messages %}
      {% include 'viewsets/includes/_messages.html' %}
    {% endblock %}

    <div class="card">
      <div class="card-header">
        <h3 class="mb-0">
          {% block body_title %}{% endblock %}
          {% block title_buttons %}{% endblock %}
        </h3>
      </div>
      <div class="card-body">
        {% block content %}{% endblock %}
      </div>
      <div class="card-footer">{% block content_footer %}{% endblock %}</div>
    </div>
  </main>
{% endblock %}


{% block js %}
  <script src="{{ static('viewsets/js/viewsets.js') }}"></script>
{% endblock %}

</body>
</html>
