<div class="row bg-light p-2 mb-2" data-formset-form>
  <div class="col">
    {% for field in form %}
      {% include 'viewsets/includes/_form_field.html' %}
    {% endfor %}
  </div>
  <div class="col-2 text-right">
    {% if formset.can_order %}
      <button type="button" class="btn btn-light btn-sm mb-1" data-formset-move-up-button>
        <i class="fa fa-arrow-up"></i>
      </button>
      <button type="button" class="btn btn-light btn-sm mb-1" data-formset-move-down-button>
        <i class="fa fa-arrow-down"></i>
      </button>
    {% endif %}
    {% if formset.can_delete %}
      <button type="button" class="btn btn-sm btn-light" data-formset-delete-button>
        <i class="fa fa-trash-alt"></i>
      </button>
    {% endif %}
  </div>
</div>