a.unlink, a.unlink:hover {
    color: inherit;
    text-decoration: none;
}

.listTable td {
    max-width: 10em;
}

.dropdown-toggle[aria-expanded="true"]:after {
    transform: rotate(180deg);
}

div[data-formset-form-deleted] {
    display: none;
}

.js-related-lookup:focus {
    box-shadow: none;
}

.card-footer:empty {
    display: none
}

.select2 {
    width: 100% !important;
}
