{% if sorting %}
  <a href="#" data-order="{{ direction }}{{ param }}" class="js-order-link unlink">
    {{ title }}
    <i class="fa fa-sort{% if is_ordered %}-{{ direction|yesno:'up,down' }}{% endif %}"></i>
  </a>
{% else %}
  {{ title }}
{% endif %}