{% load staticfiles %}<!doctype html>
<html class="no-js" lang="">
<head>
  <meta charset="utf-8">
  <meta http-equiv="x-ua-compatible" content="ie=edge">
  <title>{% block title %}{% endblock %}</title>
  <meta name="description" content="">
  <meta name="viewport" content="width=device-width, initial-scale=1, shrink-to-fit=no">

  {% block css %}
    <link rel="stylesheet" href="https://stackpath.bootstrapcdn.com/bootstrap/4.3.1/css/bootstrap.min.css"
          integrity="sha384-ggOyR0iXCbMQv3Xipma34MD+dH/1fQ784/j6cY/iJTQUOhcWr7x9JvoRxT2MZw1T" crossorigin="anonymous">
    <link rel="stylesheet" href="//use.fontawesome.com/releases/v5.3.1/css/all.css"
          integrity="sha384-mzrmE5qonljUremFsqc01SB46JvROS7bZs3IO2EmfFsd15uHvIt+Y8vEf7N7fWAU"
          crossorigin="anonymous">
    <link rel="stylesheet" href="{% static 'viewsets/css/viewsets.css' %}">
  {% endblock %}

  <script src="//code.jquery.com/jquery-3.3.1.min.js" integrity="sha256-FgpCb/KJQlLNfOu91ta32o/NMZxltwRo8QtmkMRdAu8="
          crossorigin="anonymous"></script>
  <script src="https://cdnjs.cloudflare.com/ajax/libs/popper.js/1.14.7/umd/popper.min.js"
          integrity="sha384-UO2eT0CpHqdSJQ6hJty5KVphtPhzWj9WO1clHTMGa3JDZwrnQq4sF86dIHNDz0W1"
          crossorigin="anonymous"></script>
  <script src="https://stackpath.bootstrapcdn.com/bootstrap/4.3.1/js/bootstrap.min.js"
          integrity="sha384-JjSmVgyd0p3pXB1rRibZUAYoIIy6OrQ6VrjIEaFf/nJGzIxFDsf4x0xIM+B07jRM"
          crossorigin="anonymous"></script>
  <script src="{% static 'viewsets/js/related.js' %}"></script>
  {% block extrahead %}{% endblock %}
</head>
<body>

{% block body %}
  <main role="main" class="container my-3">
    {% block breadcrumbs %}
      {% spaceless %}
        {% if not is_popup %}
          <nav aria-label="breadcrumb">
            <ul class="breadcrumb">
              {% block breadcrumbs_items %}{% endblock %}
            </ul>
          </nav>
        {% endif %}
      {% endspaceless %}
    {% endblock %}

    {% block messages %}
      {% include 'viewsets/includes/_messages.html' %}
    {% endblock %}

    <div class="card">
      <div class="card-header">
        <h3 class="mb-0">
          {% block body_title %}{% endblock %}
          {% block title_buttons %}{% endblock %}
        </h3>
      </div>
      <div class="card-body">
        {% block content %}{% endblock %}
      </div>
      <div class="card-footer">{% block content_footer %}{% endblock %}</div>
    </div>
  </main>
{% endblock %}


{% block js %}
  <script src="{% static 'viewsets/js/viewsets.js' %}"></script>
{% endblock %}

</body>
</html>
